@@ -1,51 +1,51 @@
 #' Plot hidden Markov models
-#' 
-#' Function \code{plot.hmm} plots a directed graph with pie charts of 
+#'
+#' Function \code{plot.hmm} plots a directed graph with pie charts of
 #' emission probabilities as vertices/nodes.
-#' 
+#'
 #' @export
-#' @param x A hidden Markov model object of class \code{hmm} created with 
-#'   \code{\link{build_hmm}} (or \code{\link{build_mm}}). Multichannel 
-#'   \code{hmm} objects are automatically transformed into single-channel objects. 
-#'   See function \code{\link{mc_to_sc}} for more information on the 
+#' @param x A hidden Markov model object of class \code{hmm} created with
+#'   \code{\link{build_hmm}} (or \code{\link{build_mm}}). Multichannel
+#'   \code{hmm} objects are automatically transformed into single-channel objects.
+#'   See function \code{\link{mc_to_sc}} for more information on the
 #'   transformation.
-#' @param layout specifies the layout of vertices (nodes). Accepts a 
-#'   numerical matrix, a \code{\link[igraph]{layout}} function (without quotation marks), 
-#'   or either of the predefined options \code{"horizontal"} (the 
-#'   default) and \code{"vertical"}. Options \code{"horizontal"} and 
-#'   \code{"vertical"} position vertices at the same horizontal or vertical 
-#'   line. A two-column numerical matrix can be used to give x and y coordinates of 
-#'   the vertices. The \code{\link[igraph]{layout}} functions available in the 
+#' @param layout specifies the layout of vertices (nodes). Accepts a
+#'   numerical matrix, a \code{\link[igraph]{layout_}} function (without quotation marks),
+#'   or either of the predefined options \code{"horizontal"} (the
+#'   default) and \code{"vertical"}. Options \code{"horizontal"} and
+#'   \code{"vertical"} position vertices at the same horizontal or vertical
+#'   line. A two-column numerical matrix can be used to give x and y coordinates of
+#'   the vertices. The \code{\link[igraph]{layout_}} functions available in the
 #'   \code{igraph} package offer other automatic layouts for graphs.
-#' @param pie Are vertices plotted as pie charts of emission probabilities? 
+#' @param pie Are vertices plotted as pie charts of emission probabilities?
 #'   Defaults to TRUE.
-#' @param vertex.size Size of vertices, given as a scalar or numerical 
+#' @param vertex.size Size of vertices, given as a scalar or numerical
 #'   vector. The default value is 40.
-#' @param vertex.label Labels for vertices. Possible options include 
-#'   \code{"initial.probs"}, \code{"names"}, \code{NA}, and a character or 
-#'   numerical vector. The default \code{"initial.probs"} prints the initial 
-#'   probabilities of the model and \code{"names"} prints the names of the 
+#' @param vertex.label Labels for vertices. Possible options include
+#'   \code{"initial.probs"}, \code{"names"}, \code{NA}, and a character or
+#'   numerical vector. The default \code{"initial.probs"} prints the initial
+#'   probabilities of the model and \code{"names"} prints the names of the
 #'   hidden states as labels. \code{NA} prints no labels.
-#' @param vertex.label.dist Distance of the label of the vertex from its 
-#'   center. The default value \code{"auto"} places the label outside the 
+#' @param vertex.label.dist Distance of the label of the vertex from its
+#'   center. The default value \code{"auto"} places the label outside the
 #'   vertex.
-#' @param vertex.label.pos Positions of vertex labels, relative to 
-#'   the center of the vertex. A scalar or numerical vector giving 
-#'   position(s) as radians or one of \code{"bottom"} (\code{pi/2} as radians), 
-#'   \code{"top"} (\code{-pi/2}), \code{"left"} (\code{pi}), or 
+#' @param vertex.label.pos Positions of vertex labels, relative to
+#'   the center of the vertex. A scalar or numerical vector giving
+#'   position(s) as radians or one of \code{"bottom"} (\code{pi/2} as radians),
+#'   \code{"top"} (\code{-pi/2}), \code{"left"} (\code{pi}), or
 #'   \code{"right"} (\code{0}).
 #' @param vertex.label.family,edge.label.family Font family to be used for
 #'   vertex/edge labels. See argument \code{family} in \code{\link{par}} for
 #'   more information.
 #' @param loops Defines whether transitions back to same states are plotted.
-#' @param edge.curved Defines whether to plot curved edges (arcs, arrows) 
-#'   between vertices. A logical or numerical vector or scalar. Numerical 
-#'   values specify curvatures of edges. The default value \code{TRUE} 
-#'   gives curvature of 0.5 to all edges. See \code{\link{igraph.plotting}} for 
+#' @param edge.curved Defines whether to plot curved edges (arcs, arrows)
+#'   between vertices. A logical or numerical vector or scalar. Numerical
+#'   values specify curvatures of edges. The default value \code{TRUE}
+#'   gives curvature of 0.5 to all edges. See \code{\link{igraph.plotting}} for
 #'   more information.
-#' @param edge.label Labels for edges. Possible options include 
-#'   \code{"auto"}, \code{NA}, and a character or numerical vector. The 
-#'   default \code{"auto"} prints transition probabilities as edge labels. 
+#' @param edge.label Labels for edges. Possible options include
+#'   \code{"auto"}, \code{NA}, and a character or numerical vector. The
+#'   default \code{"auto"} prints transition probabilities as edge labels.
 #'   \code{NA} prints no labels.
 #' @param edge.width Width(s) for edges. The default \code{"auto"} determines
 #'   widths according to transition probabilities between hidden states.
@@ -54,60 +54,60 @@
 #' @param edge.arrow.size Size of the arrow in edges (constant). Defaults to 1.5.
 #' @param label.signif Rounds labels of model parameters to specified number
 #'   of significant digits, 2 by default. Ignored for user-given labels.
-#' @param label.scientific Defines if scientific notation should be used to 
-#'   describe small numbers. Defaults to \code{FALSE}, e.g. 0.0001 instead of 
+#' @param label.scientific Defines if scientific notation should be used to
+#'   describe small numbers. Defaults to \code{FALSE}, e.g. 0.0001 instead of
 #'   1e-04. Ignored for user-given labels.
-#' @param label.max.length Maximum number of digits in labels of model 
+#' @param label.max.length Maximum number of digits in labels of model
 #'   parameters. Ignored for user-given labels.
-#' @param trim Scalar between 0 and 1 giving the highest probability of 
+#' @param trim Scalar between 0 and 1 giving the highest probability of
 #'   transitions that are plotted as edges, defaults to 1e-15.
 #' @param combine.slices Scalar between 0 and 1 giving the highest probability
-#'   of emission probabilities that are combined into one state. The dafault 
+#'   of emission probabilities that are combined into one state. The dafault
 #'   value is 0.05.
-#' @param combined.slice.color Color of the combined slice that includes 
-#'   the smallest emission probabilities (only if argument 
+#' @param combined.slice.color Color of the combined slice that includes
+#'   the smallest emission probabilities (only if argument
 #'   \code{"combine.slices"} is greater than 0). The default color is white.
-#' @param combined.slice.label The label for combined states (when argument 
+#' @param combined.slice.label The label for combined states (when argument
 #'   \code{"combine.slices"} is greater than 0) to appear in the legend.
-#' @param withlegend Defines if and where the legend of state colors is 
-#'   plotted. Possible values include \code{"bottom"} (the default), 
-#'   \code{"top"}, \code{"left"}, and \code{"right"}. \code{FALSE} omits the 
+#' @param withlegend Defines if and where the legend of state colors is
+#'   plotted. Possible values include \code{"bottom"} (the default),
+#'   \code{"top"}, \code{"left"}, and \code{"right"}. \code{FALSE} omits the
 #'   legend.
 #' @param ltext Optional description of (combined) observed states to appear
 #'   in the legend. A vector of character strings. See \code{\link{seqplot}} for
 #'   more information.
-#' @param legend.prop Proportion used for plotting the legend. A scalar between 
+#' @param legend.prop Proportion used for plotting the legend. A scalar between
 #'   0 and 1, defaults to 0.5.
-#' @param cex.legend Expansion factor for setting the size of the font for 
-#'   labels in the legend. The default value is 1. Values lesser than 1 will 
+#' @param cex.legend Expansion factor for setting the size of the font for
+#'   labels in the legend. The default value is 1. Values lesser than 1 will
 #'   reduce the size of the font, values greater than 1 will increase the size.
-#' @param ncol.legend The number of columns for the legend. The default value 
+#' @param ncol.legend The number of columns for the legend. The default value
 #'   \code{"auto"} sets the number of columns automatically.
 #' @param cpal Optional color palette for (combinations of) observed states.
-#'   The default value \code{"auto"} uses automatic color palette. Otherwise a 
-#'   vector of length \code{x$n_symbols} is given, i.e. the argument requires a color 
-#'   specified for all (combinations of) observed states even if they are not 
+#'   The default value \code{"auto"} uses automatic color palette. Otherwise a
+#'   vector of length \code{x$n_symbols} is given, i.e. the argument requires a color
+#'   specified for all (combinations of) observed states even if they are not
 #'   plotted (if the probability is less than \code{combine.slices}).
 #' @param main Main title for the plot. Omitted by default.
-#' @param ... Other parameters passed on to \code{\link{plot.igraph}} such as 
+#' @param ... Other parameters passed on to \code{\link{plot.igraph}} such as
 #'   \code{vertex.color}, \code{vertex.label.cex}, or \code{edge.lty}.
-#'   
-#' @seealso \code{\link{build_hmm}} and \code{\link{fit_model}} for building and 
-#'   fitting Hidden Markov models, \code{\link{mc_to_sc}} for transforming 
+#'
+#' @seealso \code{\link{build_hmm}} and \code{\link{fit_model}} for building and
+#'   fitting Hidden Markov models, \code{\link{mc_to_sc}} for transforming
 #'   multistate \code{hmm} objects into single-channel objects,
-#'   \code{\link{hmm_biofam}} and \code{\link{hmm_mvad}} for information on the models 
-#'   used in the examples, and 
+#'   \code{\link{hmm_biofam}} and \code{\link{hmm_mvad}} for information on the models
+#'   used in the examples, and
 #'   \code{\link{plot.igraph}} for the general plotting function of directed graphs.
-#'   
-#' @examples 
+#'
+#' @examples
 #' # Multichannel data, left-to-right model
-#' 
+#'
 #' # Loading a HMM of the biofam data
-#' data(hmm_biofam)
-#'   
-#' # Plotting hmm object 
+#' data("hmm_biofam")
+#'
+#' # Plotting hmm object
 #' plot(hmm_biofam)
-#' 
+#'
 #' # Plotting HMM with
 #' plot(hmm_biofam,
 #'   # varying curvature of edges
@@ -116,7 +116,7 @@
 #'   ncol.legend = 2, legend.prop = 0.4,
 #'   # new label for combined slice
 #'   combined.slice.label = "States with probability < 0.05")
-#' 
+#'
 #' # Plotting HMM with given coordinates
 #' plot(hmm_biofam,
 #'   # layout given in 2x5 matrix
@@ -140,14 +140,16 @@
 #'   combine.slices = 0,
 #'   # legend with two columns
 #'   ncol.legend = 2)
-#' 
-#' # Plotting HMM with own color palette 
-#' plot(hmm_biofam, cpal = 1:10, 
+#'
+#' # Plotting HMM with own color palette
+#' plot(hmm_biofam, cpal = 1:10,
 #'   # States with emission probability less than 0.2 removed
-#'   combine.slices = 0.2)
-#'   
+#'   combine.slices = 0.2,
+#'   # legend with two columns
+#'   ncol.legend = 2)
+#'
 #' # Plotting HMM without pie graph and with a layout function
-#' require(igraph)
+#' require("igraph")
 #' # Setting the seed for a random layout
 #' set.seed(1234)
 #' plot(hmm_biofam,
@@ -170,48 +172,48 @@
 #'   vertex.label.dist = 0,
 #'   # Fix x-axis (more space on the right-hand side)
 #'   xlim = c(-1, 1.3))
-#'      
-#' 
+#'
+#'
 #' # Single-channel data, unrestricted model
-#' 
+#'
 #' # Loading a hidden Markov model of the mvad data (hmm object)
-#' data(hmm_mvad)
-#' 
+#' data("hmm_mvad")
+#'
 #' # Plotting HMM
 #' plot(hmm_mvad)
-#' 
-#' require(igraph)
-#' plot(hmm_mvad, 
+#'
+#' require("igraph")
+#' plot(hmm_mvad,
 #'   # Layout in circle (layout function from igraph)
-#'   layout = layout_in_circle, 
-#'   # Less curved edges with smaller arrows
-#'   edge.curved = 0.2, edge.arrow.size = 0.9, 
+#'   layout = layout_in_circle,
+#'   # Less curved edges with smaller arrows, no labels
+#'   edge.curved = 0.2, edge.arrow.size = 0.9, edge.label = NA,
 #'   # Vertex labels (initial probabilities) on left
-#'   vertex.label.pos = "left", 
+#'   vertex.label.pos = c("right", "right", "left", "left", "right"),
 #'   # Less space for the legend
 #'   legend.prop = 0.3)
 
 
 
-plot.hmm  <- function(x, layout = "horizontal", pie = TRUE, 
-                      vertex.size = 40, vertex.label = "initial.probs", 
+plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
+                      vertex.size = 40, vertex.label = "initial.probs",
                       vertex.label.dist = "auto", vertex.label.pos = "bottom",
                       vertex.label.family = "sans",
-                      loops = FALSE, edge.curved = TRUE, edge.label = "auto", 
-                      edge.width = "auto", cex.edge.width = 1, 
+                      loops = FALSE, edge.curved = TRUE, edge.label = "auto",
+                      edge.width = "auto", cex.edge.width = 1,
                       edge.arrow.size = 1.5, edge.label.family = "sans",
                       label.signif = 2, label.scientific = FALSE, label.max.length = 6,
-                      trim = 1e-15, 
-                      combine.slices = 0.05, combined.slice.color = "white", 
+                      trim = 1e-15,
+                      combine.slices = 0.05, combined.slice.color = "white",
                       combined.slice.label = "others",
-                      withlegend = "bottom", ltext = NULL, legend.prop = 0.5, 
-                      cex.legend = 1, ncol.legend = "auto", cpal = "auto", 
+                      withlegend = "bottom", ltext = NULL, legend.prop = 0.5,
+                      cex.legend = 1, ncol.legend = "auto", cpal = "auto",
                       main = NULL, ...){
-  
-  
+
+
   # Saving and changing marginals
   oldPar  <- par(no.readonly = TRUE)
-  
+
   if (is.null(main)) {
     par(mar = c(0.5, 0.5, 0.5, 0.5))
   } else {
@@ -219,9 +221,9 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
   }
   on.exit(par(oldPar), add = TRUE)
   on.exit(par(mfrow = c(1, 1)), add = TRUE)
-  
+
   dots  <- list(...)
-  
+
   labelprint  <- function(z, labs) {
     if (labs == TRUE && (z > 0.001 || z == 0)) {
       labs  <- FALSE
@@ -232,22 +234,22 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
       z  <- prettyNum(signif(z, digits = label.signif), scientific = labs)
     }
   }
-  
+
   if (!is.matrix(layout) && !is.function(layout)) {
     if (!(layout %in% c("horizontal", "vertical"))) {
       stop("Argument layout only accepts numerical matrices, igraph layout functions, or strings \"horizontal\" and \"vertical\".")
     }
   }
-  
+
   if (!is.numeric(vertex.label.pos)) {
     choices <- c("bottom", "top", "left", "right")
-    ind <- pmatch(vertex.label.pos, choices)
-    if (is.na(ind)) {
+    ind <- pmatch(vertex.label.pos, choices, duplicates.ok = TRUE)
+    if (any(is.na(ind))) {
       stop("Argument vertex.label.pos only accepts values \"bottom\", \"top\", \"left\", \"right\" or a numerical vector.")
     }
     vertex.label.pos <- choices[ind]
   }
-  
+
   choices <- c(TRUE, FALSE, "bottom", "top", "left", "right")
   ind <- pmatch(withlegend, choices)
   if (is.na(ind)) {
@@ -257,32 +259,36 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
   if (withlegend %in% c(TRUE, "auto")){
     withlegend <- "right"
   }
-  
-  
+
+
   # Convert multichannel models to single-channel
   if (x$n_channels > 1) {
     x  <- mc_to_sc(x)
   }
-  
+
   # No slices -> no legends needed
   if (pie == FALSE && withlegend != FALSE) {
     withlegend  <- FALSE
   }
-  
-  
+
+
   # Positions of vertex labels
   if (!is.numeric(vertex.label.pos)) {
-    if (vertex.label.pos == "bottom") {
-      vertex.label.pos  <- pi/2
-    } else if(vertex.label.pos == "top") {
-      vertex.label.pos  <- -pi/2
-    } else if(vertex.label.pos == "left") {
-      vertex.label.pos  <- pi
-    } else {
-      vertex.label.pos  <- 0
+    vpos <- numeric(length(vertex.label.pos))
+    for(i in 1:length(vertex.label.pos)){
+      if (vertex.label.pos[i] == "bottom") {
+        vpos[i]  <- pi/2
+      } else if(vertex.label.pos[i] == "top") {
+        vpos[i]  <- -pi/2
+      } else if(vertex.label.pos[i] == "left") {
+        vpos[i]  <- pi
+      } else {
+        vpos[i]  <- 0
+      }
     }
+    vertex.label.pos <- vpos
   }
-  
+
   # Vertex labels
   if (length(vertex.label) == 1 && !is.na(vertex.label) && vertex.label != FALSE) {
     if (vertex.label == "initial.probs") {
@@ -294,7 +300,7 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
     warning("The length of the vector provided for the argument \"vertex.label\" does not match the number of hidden states.")
     vertex.label  <- rep(vertex.label, length.out = length(x$state_names))
   }
-  
+
   # Vertex label distances
   if (is.character(vertex.label.dist)) {
     ind <- pmatch(vertex.label.dist, "auto")
@@ -306,12 +312,12 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
     warning("The length of the vector provided for the argument \"vertex.label.dist\" does not match the number of edges.")
     vertex.label.dist  <- rep(vertex.label.dist, length.out = length(x$n_states))
   }
-  
-  
+
+
   # Trimming (remove small transition probablities from plot)
   transM  <- x$transition_probs
   transM[transM < trim]  <- 0
-  
+
   # Adjacency matrix (which edges to plot)
   edges  <- transM
   edges[edges > 0]  <- 1
@@ -319,14 +325,14 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
   if(!loops){
     diag(edges)  <- 0
   }
-  
+
   # Vector of non-zero transition probabilities
   transitions  <- transM
   if (loops == FALSE && length(transitions) > 1) {
     diag(transitions)  <- 0
   }
   transitions  <- t(transitions)[t(transitions) > 0]
-  
+
   # Edge labels
   if (!is.na(edge.label) && edge.label != FALSE) {
     if (length(edge.label) == 1 && (edge.label == "auto" || edge.label == TRUE)) {
@@ -336,8 +342,8 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
       edge.label  <- rep(edge.label, length.out = length(transitions))
     }
   }
-  
-  
+
+
   # Edge widths
   if (is.character(edge.width)) {
     ind <- pmatch(edge.width, "auto")
@@ -349,10 +355,10 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
     warning("The length of the vector provided for the argument \"edge.width\" does not match the number of edges.")
     edge.width  <- rep(edge.width, length.out = length(transitions))
   }
-  
+
   # Defining the graph structure
   g1  <- graph.adjacency(edges, mode = "directed")
-  
+
   # Layout of the graph
   if (is.function(layout)) {
     glayout  <- layout(g1)
@@ -365,8 +371,8 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
       glayout  <- layout_on_grid(g1, width = 1)
     }
   }
-  
-  
+
+
   # Colors for the (combinations of) observed states
   if (length(cpal) == 1 && cpal == "auto") {
     pie.colors  <- attr(x$observations, "cpal")
@@ -381,7 +387,7 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
   if (withlegend != FALSE) {
     pie.colors.l  <- pie.colors
   }
-  
+
   # Legend position and number of columns
   if (withlegend != FALSE && pie == TRUE) {
     if (!is.null(ltext)) {
@@ -396,10 +402,10 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
       graphics::layout(matrix(1:2, nrow = 2), heights = c(1 - legend.prop, legend.prop))
     } else {
       graphics::layout(matrix(2:1, nrow = 2), heights = c(legend.prop, 1 - legend.prop))
-    } 
+    }
     par(cex = 1)
   }
-  
+
   # Defining rescale, xlim, ylim if not given
   if (!is.matrix(layout) && !is.function(layout)) {
     if (layout == "horizontal") {
@@ -453,13 +459,13 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
       dots[["rescale"]]  <- NULL
     }
   }
-  
-  
+
+
   # Plotting graph
   if (pie == TRUE) {
     pie.values  <- lapply(seq_len(nrow(transM)), function(i) x$emission_probs[i,])
     # If slices are combined
-    if (combine.slices > 0 && 
+    if (combine.slices > 0 &&
         !all(unlist(pie.values)[unlist(pie.values) > 0] > combine.slices)) {
       if (withlegend != FALSE) {
         pie.colors.l  <- NULL
@@ -474,11 +480,10 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
         pie.values[[i]]  <- c(pie.values[[i]], cs.prob)
         # Texts and colors for legends
         if (withlegend != FALSE) {
-          pie.colors.l  <- c(pie.colors.l, pie.colors[pie.values[[i]] >= combine.slices])
-          lt  <- c(lt, ltext[pie.values[[i]] >= combine.slices])
+          pie.colors.l  <- c(pie.colors.l, pie.colors[pie.values[[i]][1:(length(pie.values[[i]]) - 1)] >= combine.slices])
+          lt  <- c(lt, ltext[pie.values[[i]][1:(length(pie.values[[i]]) - 1)] >= combine.slices])
         }
       }
-      pie.colors  <- c(pie.colors, combined.slice.color)
       if (withlegend != FALSE) {
         ltext  <- c(unique(lt), combined.slice.label)
         pie.colors.l  <- c(unique(pie.colors.l), combined.slice.color)
@@ -490,6 +495,7 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
           ncol.legend  <- 1
         }
       }
+      pie.colors <- c(pie.colors, combined.slice.color)
       # Slices not combined
     } else {
       if (ncol.legend == "auto") {
@@ -500,32 +506,32 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
         }
       }
     }
-    
-    if (!is.matrix(layout) && !is.function(layout) && 
+
+    if (!is.matrix(layout) && !is.function(layout) &&
         (layout == "horizontal" || layout == "vertical")) {
-      do.call(plot.igraph2, c(list(g1, layout = glayout, 
+      do.call(plot.igraph2, c(list(g1, layout = glayout,
                                    vertex.shape = "pie", vertex.pie = pie.values,
                                    vertex.pie.color = list(pie.colors),
-                                   vertex.size = vertex.size, 
-                                   vertex.label = vertex.label, vertex.label.dist = vertex.label.dist, 
+                                   vertex.size = vertex.size,
+                                   vertex.label = vertex.label, vertex.label.dist = vertex.label.dist,
                                    vertex.label.degree = vertex.label.pos,
                                    vertex.label.family = vertex.label.family,
-                                   edge.curved = edge.curved, edge.width = edge.width, 
-                                   edge.label = edge.label, 
-                                   edge.label.family = edge.label.family, 
+                                   edge.curved = edge.curved, edge.width = edge.width,
+                                   edge.label = edge.label,
+                                   edge.label.family = edge.label.family,
                                    edge.arrow.size = edge.arrow.size,
                                    xlim = xlim, ylim = ylim, rescale = rescale,
                                    main = main), dots))
     } else {
-      do.call(plot.igraph2, c(list(g1, layout = glayout, 
+      do.call(plot.igraph2, c(list(g1, layout = glayout,
                                    vertex.shape = "pie", vertex.pie = pie.values,
                                    vertex.pie.color = list(pie.colors),
-                                   vertex.size = vertex.size, 
-                                   vertex.label = vertex.label, vertex.label.dist = vertex.label.dist, 
+                                   vertex.size = vertex.size,
+                                   vertex.label = vertex.label, vertex.label.dist = vertex.label.dist,
                                    vertex.label.degree = vertex.label.pos,
                                    vertex.label.family = vertex.label.family,
-                                   edge.curved = edge.curved, edge.width = edge.width, 
-                                   edge.label = edge.label, 
+                                   edge.curved = edge.curved, edge.width = edge.width,
+                                   edge.label = edge.label,
                                    edge.label.family = edge.label.family,
                                    edge.arrow.size = edge.arrow.size,
                                    main = main), dots))
@@ -533,36 +539,36 @@ plot.hmm  <- function(x, layout = "horizontal", pie = TRUE,
   # pie = FALSE
   } else {
     if(!is.matrix(layout) && !is.function(layout) && (layout == "horizontal" || layout == "vertical")){
-      do.call(plot.igraph2, c(list(g1, layout = glayout, 
-                                   vertex.size = vertex.size, 
-                                   vertex.label = vertex.label, vertex.label.dist = vertex.label.dist, 
+      do.call(plot.igraph2, c(list(g1, layout = glayout,
+                                   vertex.size = vertex.size,
+                                   vertex.label = vertex.label, vertex.label.dist = vertex.label.dist,
                                    vertex.label.degree = vertex.label.pos,
                                    vertex.label.family = vertex.label.family,
-                                   edge.curved = edge.curved, edge.width = edge.width, 
-                                   edge.label = edge.label, 
-                                   edge.label.family = edge.label.family, 
+                                   edge.curved = edge.curved, edge.width = edge.width,
+                                   edge.label = edge.label,
+                                   edge.label.family = edge.label.family,
                                    xlim = xlim, ylim = ylim, rescale = rescale,
                                    main = main), dots))
     } else {
-      do.call(plot.igraph2, c(list(g1, layout = glayout, 
-                                   vertex.size = vertex.size, 
-                                   vertex.label = vertex.label, vertex.label.dist = vertex.label.dist, 
+      do.call(plot.igraph2, c(list(g1, layout = glayout,
+                                   vertex.size = vertex.size,
+                                   vertex.label = vertex.label, vertex.label.dist = vertex.label.dist,
                                    vertex.label.degree = vertex.label.pos,
                                    vertex.label.family = vertex.label.family,
-                                   edge.curved = edge.curved, edge.width = edge.width, 
-                                   edge.label = edge.label, 
+                                   edge.curved = edge.curved, edge.width = edge.width,
+                                   edge.label = edge.label,
                                    edge.label.family = edge.label.family,
                                    main = main), dots))
     }
-  }  
-  
-  
+  }
+
+
   # Plotting legend
   if (withlegend != FALSE && pie == TRUE) {
-    seqlegend(x$observations, cpal = pie.colors.l, ltext = ltext, 
+    seqlegend(x$observations, cpal = pie.colors.l, ltext = ltext,
               position = "center", fontsize = cex.legend, ncol = ncol.legend,
               with.missing = FALSE)
   }
-  
+
   par(mfrow = c(1, 1))
-}
\ No newline at end of file
+}
